@@ -139,12 +139,10 @@ class ativo():
         ativo.codigo = '' #ok
         ativo.preco_sobre_vpa = 0 #ok
         ativo.cotas_emitidas = 0
-        ativo.data_base = ''
-        ativo.data_base_str = ''
-        ativo.data_constituicao = ''
-        ativo.data_pagamento = ''
-        ativo.data_pagamento_str = ''
-        ativo.data_registro_cvm = ''
+        ativo.data_base = datetime.datetime.strptime('01/01/1900', "%d/%m/%Y")
+        ativo.data_constituicao = datetime.datetime.strptime('01/01/1900', "%d/%m/%Y")
+        ativo.data_pagamento = datetime.datetime.strptime('01/01/1900', "%d/%m/%Y")
+        ativo.data_registro_cvm = datetime.datetime.strptime('01/01/1900', "%d/%m/%Y")
         ativo.dy = 0
         ativo.dy_projetado = 0
         ativo.dy_acum_12m = 0
@@ -199,7 +197,7 @@ class ativo():
         ativo.cod_tipo_gestao = 1
         ativo.ultima_valorizacao = 0
         ativo.ultimo_preco = 0
-        ativo.data_ultimo_preco = 0
+        ativo.data_ultimo_preco = datetime.datetime.strptime('01/01/1900', "%d/%m/%Y")
         ativo.ultimo_rendimento_brl = 0
         ativo.ultimo_rendimento_perc = 0
         ativo.vacancia_financeira = 0
@@ -487,16 +485,16 @@ class fii:
                     #_ativo.administrador = funcs.clean_text(estrutura[int_contador_itens + 3])  # primeira fonte
                     _ativo.ultimo_rendimento_brl = funcs.num_ptb2us(estrutura[int_contador_itens + 4])
                     _ativo.ultimo_rendimento_perc = funcs.num_ptb2us(estrutura[int_contador_itens + 5])/100
-                    _ativo.data_pagamento_str = funcs.clean_text(estrutura[int_contador_itens + 6])
+                    data_pagamento_str = funcs.clean_text(estrutura[int_contador_itens + 6])
                     try:
-                        _ativo.data_pagamento = datetime.datetime.strptime(_ativo.data_pagamento_str,'%d/%m/%y')
+                        _ativo.data_pagamento = datetime.datetime.strptime(data_pagamento_str,'%d/%m/%y')
                     except ValueError:
-                        _ativo.data_pagamento = None
-                    _ativo.data_base_str = funcs.clean_text(estrutura[int_contador_itens + 7])
+                        pass
+                    data_base_str = funcs.clean_text(estrutura[int_contador_itens + 7])
                     try:
-                        _ativo.data_base = datetime.datetime.strptime(_ativo.data_base_str,'%d/%m/%y')
+                        _ativo.data_base = datetime.datetime.strptime(data_base_str,'%d/%m/%y')
                     except ValueError:
-                        _ativo.data_base = None
+                        pass
                     _ativo.rendimento_medio_12m_brl = funcs.num_ptb2us(estrutura[int_contador_itens + 8])
                     _ativo.rendimento_medio_12m_perc = funcs.num_ptb2us(estrutura[int_contador_itens + 9])/100
                     _ativo.valor_patrimonial = funcs.num_ptb2us(estrutura[int_contador_itens + 10])
@@ -775,7 +773,11 @@ class fii:
                 lst_fiis_interno[int_pointer].cod_tipo_gestao = codigos_tipo_gestao['PASSIVA']
             else:
                 lst_fiis_interno[int_pointer].cod_tipo_gestao = codigos_tipo_gestao['N/A']
-            lst_fiis_interno[int_pointer].data_registro_cvm  = funcs.clean_text(estrutura[dic_estrutura_dinamica['REGISTRO CVM']+2])
+            data_registro_cvm = funcs.clean_text(estrutura[dic_estrutura_dinamica['REGISTRO CVM']+2])
+            try:
+                lst_fiis_interno[int_pointer].data_registro_cvm  = datetime.datetime.strptime(data_registro_cvm,"%d/%m/%Y")
+            except ValueError:
+                pass
             lst_fiis_interno[int_pointer].numero_cotas  = funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['NÚMERO DE COTAS']+2])
             lst_fiis_interno[int_pointer].numero_cotistas  = preferencial(lst_fiis_interno[int_pointer].numero_cotistas,funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['NÚMERO DE COTISTAS']+2]))
             lst_fiis_interno[int_pointer].cnpj  = funcs.formata_cnpj(funcs.clean_text(estrutura[dic_estrutura_dinamica['CNPJ']+2]))
@@ -836,6 +838,11 @@ class fii:
             #lap3 = datetime.datetime.now() - lap
             #lap = datetime.datetime.now()
             soup = BeautifulSoup(html, "lxml")
+            browser.get('https://chart.fundsexplorer.com.br/chart/' + ticker)
+            html = browser.page_source
+            posicao_palavra_fechamento = html.find('Fechamento')
+            data_ultimo_preco = html[posicao_palavra_fechamento + 17:posicao_palavra_fechamento + 27]
+
             #lap4 = datetime.datetime.now() - lap
             #lst_tempos.append((url, lap1.total_seconds(), lap2.total_seconds(), lap3.total_seconds(), lap4.total_seconds()))
 
@@ -872,6 +879,10 @@ class fii:
                 lst_fiis_interno[int_pointer].execucao_curta = True
                 continue
             if estrutura[1] != 'Ops! Algo está errado...':
+                try:
+                    lst_fiis_interno[int_pointer].data_ultimo_preco = datetime.datetime.strptime(data_ultimo_preco,"%d/%m/%Y")
+                except ValueError:
+                    pass
                 lst_fiis_interno[int_pointer].ultimo_preco = preferencial(funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['EBOOK GRATUITO']+7]), lst_fiis_interno[int_pointer].ultimo_preco)
                 lst_fiis_interno[int_pointer].ultima_valorizacao = preferencial(funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['EBOOK GRATUITO']+8]), lst_fiis_interno[int_pointer].ultima_valorizacao)
                 lst_fiis_interno[int_pointer].liquidez_diaria = preferencial(funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['LIQUIDEZ DIÁRIA']+2]), lst_fiis_interno[int_pointer].liquidez_diaria)
@@ -889,9 +900,9 @@ class fii:
                 try:
                     str_mes_data_constituicao = str_data_constituicao[str_data_constituicao.find(' DE ')+4:str_data_constituicao.rfind(' DE ')]
                     str_data_constituicao = str_data_constituicao.replace(' DE ' + str_mes_data_constituicao + ' DE ', '/' + dic_meses[str_mes_data_constituicao]+'/')
-                except:
-                    str_data_constituicao = ''
-                lst_fiis_interno[int_pointer].data_constituicao = str_data_constituicao
+                    lst_fiis_interno[int_pointer].data_constituicao = datetime.datetime.stpftime(str_data_constituicao,"%d/%m/%Y")
+                except ValueError:
+                    pass
                 lst_fiis_interno[int_pointer].cotas_emitidas = funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['COTAS EMITIDAS']+2])
                 lst_fiis_interno[int_pointer].patrimonio_inicial = funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['PATRIMÔNIO INICIAL']+2])
                 lst_fiis_interno[int_pointer].valor_inicial_cota = funcs.num_ptb2us(estrutura[dic_estrutura_dinamica['VALOR INICIAL DA COTA']+2])
